==> schlix-cms-v2.1.8-7.zip: schlix/install/step_finish.template.php <==
<?php if (!defined('SCHLIX_INSTALLER')) die ('Please visit /install/'); ?>
<p>1. No changes in <strong> .htaccess</strong> required. As of v1.2.5 RewriteBase is no longer needed.
<?php if ($_SESSION['site_httpbase']): ?>
If you encounter an issue where URLs are not resolving, please add the following in .htaccess</p>
<h3 style="margin:0;padding:0"><span style="color:blue">RewriteBase <?= $_SESSION['site_httpbase']; ?></span></h3>
<?php endif; ?>
<p style="color:red">2. Please remember to rename/delete the <strong>install</strong> folder.</p>
<p>3. It is recommended that you password protect the <strong>/admin</strong> folder with .htaccess</p>
<p>4. You may now login to: <A href="<?= $_SESSION['site_scheme'].'://'.$_SESSION['site_domain_name_and_port'].$_SESSION['site_httpbase'].'/admin/'; ?>" target="_blank"><?= $_SESSION['site_url'].$_SESSION['site_httpbase'].'/admin/'; ?></A> with the following credentials:</p>
<div class="form-horizontal">
        <div class="form-group">
            <label for="admin_username" class="control-label col-xs-3">Admin username</label>
            <div class="col-xs-7">
                <div class="input-group">
                    <span class="input-group-addon">
                        <i class="fa fa-user"></i>
                    </span>
                    <input class="form-control" placeholder="Admin username" name="admin_username"  id="admin_username" type="text"  value="<?= trim($_SESSION['admin_username']); ?>" readonly="readonly" />

                </div>
            </div>
        </div>        


        <!-- input -->
        <div class="form-group">
            <label for="admin_password" class="control-label col-xs-3">Admin password</label>
            <div class="col-xs-7">
                <div class="input-group">
                    <span class="input-group-addon">
                        <i class="fa fa-lock"></i>
                    </span>
                    <input class="form-control" placeholder="Password" name="admin_password"  id="admin_password" type="text"  value="<?= trim($_SESSION['admin_password']); ?>" readonly="readonly" />
                </div>
            </div>
        </div>        
</div>
 
<?php if ($_POST['installsample']==1): ?>
<p>As part of the demo, you can also login to the <A href="<?= $_SESSION['site_url'].$_SESSION['site_httpbase'].'/users/'; ?>" target="_blank">front end</a> with the following username/password</p>
<div class="form-horizontal">
        <div class="form-group">
            <label for="admin_username" class="control-label col-xs-3">Test username</label>
            <div class="col-xs-7">
                <div class="input-group">
                    <span class="input-group-addon">
                        <i class="fa fa-user"></i>
                    </span>
                    <input class="form-control" placeholder="Test username" name="test_username"  id="test_password" type="text"  value="testuser" readonly="readonly" />

                </div>
            </div>
        </div>        


        <!-- input -->
        <div class="form-group">
            <label for="admin_password" class="control-label col-xs-3">Test password</label>
            <div class="col-xs-7">
                <div class="input-group">
                    <span class="input-group-addon">
                        <i class="fa fa-lock"></i>
                    </span>
                    <input class="form-control" placeholder="Test password" name="test_password"  id="test_password" type="text"  value="testuser" readonly="readonly" />
                </div>
            </div>
        </div>        
</div>
<?php endif; ?>
<br/>
<p><A href="javascript:window.print();"><i class="fa fa-print"></i> Please print this instruction for your reference</A></p>

==> schlix-cms-v2.2.7-1.zip: schlix/install/step_finish.template.php <==
<?php
if (!defined('SCHLIX_INSTALLER')) die('Please visit /install/');
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
// SCHLIX WEB CONTENT MANAGEMENT SYSTEM - Copyright (C) SCHLIX WEB INC.
// This is a SHARED SOURCE
// You may use this software commercially, but you are not allowed to create a fork or create a derivative of this software
// Please read the license for details
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

 ?>
<p>1. No changes in <strong> .htaccess</strong> required. As of v1.2.5 RewriteBase is no longer needed.
<?php if ($_SESSION['site_httpbase']): ?>
If you encounter an issue where URLs are not resolving, please add the following in .htaccess</p>
<h3 style="margin:0;padding:0"><span style="color:blue">RewriteBase <?= $_SESSION['site_httpbase']; ?></span></h3>
<?php endif; ?>
<p style="color:red">2. Please remember to rename/delete the <strong>install</strong> folder.</p>
<p>3. It is recommended that you password protect the <strong>/admin</strong> folder with .htaccess</p>
<p>4. You may now login to: <A href="<?= $_SESSION['site_scheme'].'://'.$_SESSION['site_domain_name_and_port'].$_SESSION['site_httpbase'].'/admin/'; ?>" target="_blank"><?= $_SESSION['site_url'].$_SESSION['site_httpbase'].'/admin/'; ?></A> with the following credentials:</p>
<div class="form-horizontal">
        <div class="form-group">
            <label for="admin_username" class="control-label col-xs-3">Admin username</label>
            <div class="col-xs-7">
                <div class="input-group">
                    <span class="input-group-addon">
                        <i class="fas fa-user"></i>
                    </span>
                    <input class="form-control" placeholder="Admin username" name="admin_username"  id="admin_username" type="text"  value="<?= trim($_SESSION['admin_username']); ?>" readonly="readonly" />

                </div>
            </div>
        </div>        


        <!-- input -->
        <div class="form-group">
            <label for="admin_password" class="control-label col-xs-3">Admin password</label>
            <div class="col-xs-7">
                <div class="input-group">
                    <span class="input-group-addon">
                        <i class="fas fa-lock"></i>
                    </span>
                    <input class="form-control" placeholder="Password" name="admin_password"  id="admin_password" type="text"  value="<?= trim($_SESSION['admin_password']); ?>" readonly="readonly" />
                </div>
            </div>
        </div>        
</div>
 
<?php if ($_POST['installsample']== 2): ?>
<p>As part of the demo, you can also login to the <A href="<?= $_SESSION['site_url'].$_SESSION['site_httpbase'].'/users/'; ?>" target="_blank">front end</a> with the following username/password</p>
<div class="form-horizontal">
        <div class="form-group">
            <label for="admin_username" class="control-label col-xs-3">Test usernames</label>
            <div class="col-xs-7">
                <div class="input-group">
                    <span class="input-group-addon">
                        <i class="fas fa-user"></i>
                    </span>
                    <input class="form-control" placeholder="Test username" name="test_username"  id="test_username" type="text"  value="testuser1, testuser2, testuser3" readonly="readonly" />

                </div>
            </div>
        </div>        


        <!-- input -->
        <div class="form-group">
            <label for="admin_password" class="control-label col-xs-3">Test password</label>
            <div class="col-xs-7">
                <div class="input-group">
                    <span class="input-group-addon">
                        <i class="fas fa-lock"></i>
                    </span>
                    <input class="form-control" placeholder="Test password" name="test_password"  id="test_password" type="text"  value="(same as your admin password)" readonly="readonly" />
                </div>
            </div>
        </div>        
</div>
<?php endif; ?>
<br/>
<p><a id="btn-print" ><i class="fas fa-print"></i> Please print this instruction for your reference</A></p>
